==> qtah-qt5-0.3.0.tar.gz: qtah-qt5-0.3.0/src/Graphics/UI/Qtah/Widgets/QLineEdit.hs <==
{-# LANGUAGE CPP, FlexibleContexts, FlexibleInstances, GeneralizedNewtypeDeriving, MultiParamTypeClasses, ScopedTypeVariables, TypeSynonymInstances, UndecidableInstances #-}
#if !MIN_VERSION_base(4,8,0)
{-# LANGUAGE OverlappingInstances #-}
#endif

---------- GENERATED FILE, EDITS WILL BE LOST ----------

{-# LANGUAGE NoMonomorphismRestriction #-}

module Graphics.UI.Qtah.Widgets.QLineEdit (
  QLineEditValue (..),
  QLineEditConstPtr (..),
  QLineEditPtr (..),
  QLineEditConst,
  QLineEdit,
  castConst,
  cast,
  downCastConst,
  downCast,
  new,
  newWithParent,
  newWithText,
  newWithTextAndParent,
  alignment,
  backspace,
  clear,
  copy,
  createStandardContextMenu,
  cursorBackward,
  cursorForward,
  cursorMoveStyle,
  cursorPosition,
  cursorPositionAt,
  cursorWordBackward,
  cursorWordForward,
  cut,
  del,
  deselect,
  displayText,
  dragEnabled,
  echoMode,
  end,
  hasAcceptableInput,
  hasFrame,
  hasSelectedText,
  home,
  inputMask,
  insert,
  isModified,
  isReadOnly,
  isRedoAvailable,
  isUndoAvailable,
  maxLength,
  paste,
  placeholderText,
  redo,
  selectAll,
  selectedText,
  selectionStart,
  setAlignment,
  setCursorMoveStyle,
  setCursorPosition,
  setDragEnabled,
  setEchoMode,
  setFrame,
  setInputMask,
  setMaxLength,
  setModified,
  setPlaceholderText,
  setReadOnly,
  setSelection,
  setText,
  setTextMargins,
  setTextMarginsRaw,
  setValidator,
  text,
  textMargins,
  undo,
  validator,
  cursorPositionChangedSignal,
  editingFinishedSignal,
  returnPressedSignal,
  selectionChangedSignal,
  textEditedSignal,
  textChangedSignal,
  QLineEditEchoMode (..),
  ) where

import Graphics.UI.Qtah.Generated.Widgets.QLineEdit
import Graphics.UI.Qtah.Internal.Listener
import qualified Graphics.UI.Qtah.Signal as QtahSignal
import Prelude ()
import qualified Prelude as HoppyP
import qualified Prelude as QtahP


castConst = toQLineEditConst
cast = toQLineEdit
downCastConst = downToQLineEditConst
downCast = downToQLineEdit

cursorPositionChangedSignal :: (QLineEditPtr object) => QtahSignal.Signal object (HoppyP.Int -> HoppyP.Int -> HoppyP.IO ())
cursorPositionChangedSignal = QtahSignal.Signal
  { QtahSignal.internalConnectSignal = \object' fn' -> do
    listener' <- listenerIntInt_new fn'
    listenerIntInt_connectListener listener' object' "2cursorPositionChanged(int,int)"
  , QtahSignal.internalName = "QLineEdit::cursorPositionChanged (ListenerIntInt)"
  }

editingFinishedSignal :: (QLineEditPtr object) => QtahSignal.Signal object (HoppyP.IO ())
editingFinishedSignal = QtahSignal.Signal
  { QtahSignal.internalConnectSignal = \object' fn' -> do
    listener' <- listener_new fn'
    listener_connectListener listener' object' "2editingFinished()"
  , QtahSignal.internalName = "QLineEdit::editingFinished (Listener)"
  }

returnPressedSignal :: (QLineEditPtr object) => QtahSignal.Signal object (HoppyP.IO ())
returnPressedSignal = QtahSignal.Signal
  { QtahSignal.internalConnectSignal = \object' fn' -> do
    listener' <- listener_new fn'
    listener_connectListener listener' object' "2returnPressed()"
  , QtahSignal.internalName = "QLineEdit::returnPressed (Listener)"
  }

selectionChangedSignal :: (QLineEditPtr object) => QtahSignal.Signal object (HoppyP.IO ())
selectionChangedSignal = QtahSignal.Signal
  { QtahSignal.internalConnectSignal = \object' fn' -> do
    listener' <- listener_new fn'
    listener_connectListener listener' object' "2selectionChanged()"
  , QtahSignal.internalName = "QLineEdit::selectionChanged (Listener)"
  }

textEditedSignal :: (QLineEditPtr object) => QtahSignal.Signal object (QtahP.String -> HoppyP.IO ())
textEditedSignal = QtahSignal.Signal
  { QtahSignal.internalConnectSignal = \object' fn' -> do
    listener' <- listenerQString_new fn'
    listenerQString_connectListener listener' object' "2textEdited(QString)"
  , QtahSignal.internalName = "QLineEdit::textEdited (ListenerQString)"
  }

textChangedSignal :: (QLineEditPtr object) => QtahSignal.Signal object (QtahP.String -> HoppyP.IO ())
textChangedSignal = QtahSignal.Signal
  { QtahSignal.internalConnectSignal = \object' fn' -> do
    listener' <- listenerQString_new fn'
    listenerQString_connectListener listener' object' "2textChanged(QString)"
  , QtahSignal.internalName = "QLineEdit::textChanged (ListenerQString)"
  }

==> qtah-qt5-0.8.0.tar.gz: qtah-qt5-0.8.0/src/Graphics/UI/Qtah/Widgets/QLineEdit.hs <==
{-# LANGUAGE FlexibleContexts, FlexibleInstances, ForeignFunctionInterface, MonoLocalBinds, MultiParamTypeClasses, ScopedTypeVariables, TypeSynonymInstances, UndecidableInstances #-}
---------- GENERATED FILE, EDITS WILL BE LOST ----------

{-# LANGUAGE NoMonomorphismRestriction #-}

module Graphics.UI.Qtah.Widgets.QLineEdit (
  QLineEditValue (..),
  QLineEditConstPtr (..),
  QLineEditPtr (..),
  QLineEditConst,
  QLineEdit,
  castConst,
  cast,
  downCastConst,
  downCast,
  new,
  newWithParent,
  newWithText,
  newWithTextAndParent,
  alignment,
  backspace,
  clear,
  copy,
  createStandardContextMenu,
  cursorBackward,
  cursorForward,
  cursorMoveStyle,
  cursorPosition,
  cursorPositionAt,
  cursorWordBackward,
  cursorWordForward,
  cut,
  del,
  deselect,
  displayText,
  dragEnabled,
  echoMode,
  emitCursorPositionChanged,
  emitEditingFinished,
  emitReturnPressed,
  emitSelectionChanged,
  emitTextChanged,
  emitTextEdited,
  end,
  hasAcceptableInput,
  hasFrame,
  hasSelectedText,
  home,
  inputMask,
  insert,
  isClearButtonEnabled,
  isModified,
  isReadOnly,
  isRedoAvailable,
  isUndoAvailable,
  maxLength,
  paste,
  placeholderText,
  redo,
  selectAll,
  selectedText,
  selectionStart,
  setAlignment,
  setClearButtonEnabled,
  setCursorMoveStyle,
  setCursorPosition,
  setDragEnabled,
  setEchoMode,
  setFrame,
  setInputMask,
  setMaxLength,
  setModified,
  setPlaceholderText,
  setReadOnly,
  setSelection,
  setText,
  setTextMargins,
  setTextMarginsRaw,
  setValidator,
  text,
  textMargins,
  undo,
  validator,
  cursorPositionChangedSignal,
  editingFinishedSignal,
  returnPressedSignal,
  selectionChangedSignal,
  textEditedSignal,
  textChangedSignal,
  QLineEditEchoMode (..),
  ) where

import qualified Foreign.Hoppy.Runtime as QtahFHR
import Graphics.UI.Qtah.Generated.Widgets.QLineEdit
import Graphics.UI.Qtah.Internal.Listener
import qualified Graphics.UI.Qtah.Signal as QtahSignal
import Prelude (($), (>>))
import qualified Prelude as HoppyP
import qualified Prelude as QtahP


castConst = toQLineEditConst
cast = toQLineEdit
downCastConst = downToQLineEditConst
downCast = downToQLineEdit

cursorPositionChangedSignal :: (QLineEditPtr object) => QtahSignal.Signal object (HoppyP.Int -> HoppyP.Int -> HoppyP.IO ())
cursorPositionChangedSignal = QtahSignal.Signal
  { QtahSignal.internalConnectSignal = \object' fn' -> do
    listener' <- listenerIntInt_new object' "2cursorPositionChanged(int,int)" fn'
    valid' <- listenerIntInt_isValid listener'
    if valid'
      then QtahP.fmap QtahP.Just $ QtahSignal.internalMakeConnection listener'
      else QtahFHR.delete listener' >> QtahP.return QtahP.Nothing
  , QtahSignal.internalName = "QLineEdit::cursorPositionChanged (ListenerIntInt)"
  }

editingFinishedSignal :: (QLineEditPtr object) => QtahSignal.Signal object (HoppyP.IO ())
editingFinishedSignal = QtahSignal.Signal
  { QtahSignal.internalConnectSignal = \object' fn' -> do
    listener' <- listener_new object' "2editingFinished()" fn'
    valid' <- listener_isValid listener'
    if valid'
      then QtahP.fmap QtahP.Just $ QtahSignal.internalMakeConnection listener'
      else QtahFHR.delete listener' >> QtahP.return QtahP.Nothing
  , QtahSignal.internalName = "QLineEdit::editingFinished (Listener)"
  }

returnPressedSignal :: (QLineEditPtr object) => QtahSignal.Signal object (HoppyP.IO ())
returnPressedSignal = QtahSignal.Signal
  { QtahSignal.internalConnectSignal = \object' fn' -> do
    listener' <- listener_new object' "2returnPressed()" fn'
    valid' <- listener_isValid listener'
    if valid'
      then QtahP.fmap QtahP.Just $ QtahSignal.internalMakeConnection listener'
      else QtahFHR.delete listener' >> QtahP.return QtahP.Nothing
  , QtahSignal.internalName = "QLineEdit::returnPressed (Listener)"
  }

selectionChangedSignal :: (QLineEditPtr object) => QtahSignal.Signal object (HoppyP.IO ())
selectionChangedSignal = QtahSignal.Signal
  { QtahSignal.internalConnectSignal = \object' fn' -> do
    listener' <- listener_new object' "2selectionChanged()" fn'
    valid' <- listener_isValid listener'
    if valid'
      then QtahP.fmap QtahP.Just $ QtahSignal.internalMakeConnection listener'
      else QtahFHR.delete listener' >> QtahP.return QtahP.Nothing
  , QtahSignal.internalName = "QLineEdit::selectionChanged (Listener)"
  }

textEditedSignal :: (QLineEditPtr object) => QtahSignal.Signal object (QtahP.String -> HoppyP.IO ())
textEditedSignal = QtahSignal.Signal
  { QtahSignal.internalConnectSignal = \object' fn' -> do
    listener' <- listenerQString_new object' "2textEdited(QString)" fn'
    valid' <- listenerQString_isValid listener'
    if valid'
      then QtahP.fmap QtahP.Just $ QtahSignal.internalMakeConnection listener'
      else QtahFHR.delete listener' >> QtahP.return QtahP.Nothing
  , QtahSignal.internalName = "QLineEdit::textEdited (ListenerQString)"
  }

textChangedSignal :: (QLineEditPtr object) => QtahSignal.Signal object (QtahP.String -> HoppyP.IO ())
textChangedSignal = QtahSignal.Signal
  { QtahSignal.internalConnectSignal = \object' fn' -> do
    listener' <- listenerQString_new object' "2textChanged(QString)" fn'
    valid' <- listenerQString_isValid listener'
    if valid'
      then QtahP.fmap QtahP.Just $ QtahSignal.internalMakeConnection listener'
      else QtahFHR.delete listener' >> QtahP.return QtahP.Nothing
  , QtahSignal.internalName = "QLineEdit::textChanged (ListenerQString)"
  }
